@@ -283,7 +283,9 @@ void Battle::OnUserBattleStatusUpdated( User &user, UserBattleStatus status )
 				}
 			}
 		}
-		ui().OnUserBattleStatus( *this, user );
+	if ( !GetMe().BattleStatus().spectator ) SetAutoUnspec(false); // we don't need auto unspec anymore
+	ShouldAutoUnspec();
+	ui().OnUserBattleStatus( *this, user );
 }
 
 
@@ -291,6 +293,7 @@ void Battle::OnUserRemoved( User& user )
 {
     m_ah.OnUserRemoved(user);
     IBattle::OnUserRemoved( user );
+	ShouldAutoUnspec();
 }
 
 
@@ -1155,3 +1158,20 @@ void Battle::OnUnitsyncReloaded( GlobalEvents::GlobalEventData data )
 	if ( m_is_self_in ) SendMyBattleStatus();
 }
 
+void Battle::ShouldAutoUnspec()
+{
+	if ( m_auto_unspec && !IsLocked() && GetMe().BattleStatus().spectator )
+	{
+		if ( GetNumActivePlayers() < m_opts.maxplayers )
+		{
+			ForceSpectator(GetMe(),false);
+		}
+	}
+}
+
+void Battle::SetAutoUnspec(bool value)
+{
+	m_auto_unspec = value;
+	ShouldAutoUnspec();
+}
+
