@@ -106,6 +106,11 @@ class Battle : public IBattle
 
 	void OnUnitsyncReloaded( GlobalEvents::GlobalEventData data );
 
+	void SetAutoUnspec(bool value);
+	bool GetAutoUnspec() { return m_auto_unspec; }
+
+  void ShouldAutoUnspec();
+
   protected:
     // Battle variables
 
