@@ -297,6 +297,10 @@ ChatOptionsTab::ChatOptionsTab( wxWindow* parent )
 	sbBehaviorSizer->Add( m_play_sounds, 0, wxALL, 5 );
 #endif
 
+	m_broadcast_check = new wxCheckBox( this, wxID_ANY, _( "Copy server messages in current channel" ), wxDefaultPosition, wxDefaultSize, 0 );
+	m_broadcast_check->SetValue( sett().GetBroadcastEverywhere() );
+	sbBehaviorSizer->Add( m_broadcast_check, 0, wxALL, 5 );
+
 	bMainSizerV->Add( sbBehaviorSizer, 0, wxEXPAND | wxBOTTOM | wxRIGHT | wxLEFT, 5 );
 
 	wxBoxSizer* bBotomSizer;
@@ -343,7 +347,6 @@ ChatOptionsTab::ChatOptionsTab( wxWindow* parent )
 
 	bMainSizerV->Add( bBotomSizer, 0, wxEXPAND | wxBOTTOM | wxRIGHT | wxLEFT, 5 );
 
-
 	bMainSizerV->Add( 0, 0, 1, wxEXPAND | wxALL, 5 );
 
 	SetScrollRate( SCROLL_RATE, SCROLL_RATE );
@@ -444,6 +447,7 @@ void ChatOptionsTab::DoRestore()
 	m_play_sounds->SetValue( sett().GetChatPMSoundNotificationEnabled() );
 #endif
     m_num_lines->SetValue( sett().GetAutoloadedChatlogLinesCount() );
+	m_broadcast_check->SetValue(sett().GetBroadcastEverywhere() );
 }
 
 void ChatOptionsTab::OnApply( wxCommandEvent& /*unused*/ )
@@ -469,6 +473,8 @@ void ChatOptionsTab::OnApply( wxCommandEvent& /*unused*/ )
 	//Chat Log
 	sett().SetChatLogEnable( m_save_logs->GetValue() );
 
+	sett().SetBroadcastEverywhere( m_broadcast_check->GetValue() );
+
 	// Behavior
 #ifndef DISABLE_SOUND
 	sett().SetChatPMSoundNotificationEnabled( m_play_sounds->IsChecked() );
