@@ -27,7 +27,7 @@ class MainChatTab : public wxScrolledWindow
 
     ChatPanel& ServerChat();
 
-    ChatPanel* AddChatPanel( Channel& channel );
+	ChatPanel* AddChatPanel( Channel& channel, bool doFocus  );
     ChatPanel* AddChatPanel( Server& server, const wxString& name );
     ChatPanel* AddChatPanel( const User& user );
     /** \brief this is only used if channel is left via raw command in server tab */
