@@ -75,9 +75,9 @@ bool OptionsWrapper::loadAIOptions( const wxString& modname, int aiindex,const w
 	return true;
 }
 
-int OptionsWrapper::GetAIOptionIndex( const wxString& nick )
+int OptionsWrapper::GetAIOptionIndex( const wxString& nick ) const
 {
-	std::map<wxString,int>::iterator itor = m_ais_indexes.find(nick);
+	std::map<wxString,int>::const_iterator itor = m_ais_indexes.find(nick);
 	int pos = -1;
 	if ( itor != m_ais_indexes.end() ) pos = itor->second;
 	wxLogDebugFunc( _T("bot name: ") + nick + _T(" option index: ") + TowxString( pos ) );
@@ -100,7 +100,7 @@ bool OptionsWrapper::loadOptions( GameOption modmapFlag, const wxString& name, c
 			}
 			catch(...)
 			{
-				wxLogError(_T("Could not load map Options"));
+				wxLogError(_T("Could not load map options"));
 				return false;
 			}
 			break;
@@ -113,7 +113,7 @@ bool OptionsWrapper::loadOptions( GameOption modmapFlag, const wxString& name, c
 			}
 			catch(...)
 			{
-				wxLogError(_T("Could not load mod Options"));
+				wxLogError(_T("Could not load game options"));
 				return false;
 			}
 			break;
@@ -191,7 +191,7 @@ bool OptionsWrapper::keyExists( const wxString& key ) const
 
 bool OptionsWrapper::keyExists( const wxString& key, const GameOption modmapFlag, bool showError, OptionType& optType ) const
 {
-	wxString duplicateKeyError = _T("Please contact the mod's author and tell him\n\
+	wxString duplicateKeyError = _T("Please contact the game's author and tell him\n\
 										to use unique keys in his ModOptions.lua");
 	bool exists = false;
 	optType = opt_undefined;
@@ -240,7 +240,7 @@ bool OptionsWrapper::keyExists( const wxString& key, const GameOption modmapFlag
 
 bool  OptionsWrapper::setOptions(wxStringPairVec* options, GameOption modmapFlag)
 {
-	for (wxStringPairVec::iterator it = options->begin(); it != options->end(); ++it)
+	for (wxStringPairVec::const_iterator it = options->begin(); it != options->end(); ++it)
 	{
 		wxString key = it->first;
 		wxString value = it->second;
@@ -534,7 +534,7 @@ wxString OptionsWrapper::GetNameListOptItemKey( const wxString& optkey, const wx
                 return wxEmptyString;
 
             GameOptions tempOpt = optIt->second;
-			for (ListItemVec::iterator it = (tempOpt.list_map)[optkey].listitems.begin(); it != (tempOpt.list_map)[optkey].listitems.end(); ++it)
+			for (ListItemVec::const_iterator it = (tempOpt.list_map)[optkey].listitems.begin(); it != (tempOpt.list_map)[optkey].listitems.end(); ++it)
 			{
 				if (it->name == itemname)
 					return it->key;
@@ -577,7 +577,7 @@ void OptionsWrapper::ParseSectionMap( mmSectionTree& section_tree, const IUnitSy
 
     // map child-key <-> parent-key
     typedef std::map<wxString,wxString> RelationMap;
-    typedef std::map<wxString,wxString>::iterator RelationMapIter;
+	typedef std::map<wxString,wxString>::iterator RelationMapIter;
     RelationMap relation_map;
 
     //setup relation map
