@@ -110,7 +110,7 @@ PlaybackListFilter<PlaybackTabType>::PlaybackListFilter( wxWindow* parent, wxWin
 	wxBoxSizer* m_filter_only_map_sizer;
 	m_filter_only_map_sizer = new wxBoxSizer( wxHORIZONTAL );
 
-	m_filter_map_show = new wxCheckBox( this, PLAYBACK_FILTER_MAP_SHOW, _("Only maps i have"), wxDefaultPosition, wxSize( -1,-1 ), 0 );
+	m_filter_map_show = new wxCheckBox( this, PLAYBACK_FILTER_MAP_SHOW, _("Only maps I have"), wxDefaultPosition, wxSize( -1,-1 ), 0 );
     m_filter_map_show->SetValue(f_values.map_show);
 	m_filter_map_show->SetMinSize( wxSize( 140,-1 ) );
 
@@ -126,7 +126,7 @@ PlaybackListFilter<PlaybackTabType>::PlaybackListFilter( wxWindow* parent, wxWin
 	wxBoxSizer* m_filter_mod_sizer;
 	m_filter_mod_sizer = new wxBoxSizer( wxHORIZONTAL );
 
-	m_filter_mod_text = new wxStaticText( this, wxID_ANY, _("Mod:"), wxDefaultPosition, wxSize( -1,-1 ), 0 );
+	m_filter_mod_text = new wxStaticText( this, wxID_ANY, _("Game:"), wxDefaultPosition, wxSize( -1,-1 ), 0 );
 	m_filter_mod_text->Wrap( -1 );
 	m_filter_mod_text->SetMinSize( wxSize( 90,-1 ) );
 
@@ -143,7 +143,7 @@ PlaybackListFilter<PlaybackTabType>::PlaybackListFilter( wxWindow* parent, wxWin
 	wxBoxSizer* m_filter_only_mod_sizer;
 	m_filter_only_mod_sizer = new wxBoxSizer( wxHORIZONTAL );
 
-	m_filter_mod_show = new wxCheckBox( this, PLAYBACK_FILTER_MOD_SHOW, _("Only mods i have"), wxDefaultPosition, wxSize( -1,-1 ), 0 );
+	m_filter_mod_show = new wxCheckBox( this, PLAYBACK_FILTER_MOD_SHOW, _("Only games I have"), wxDefaultPosition, wxSize( -1,-1 ), 0 );
     m_filter_mod_show->SetValue(f_values.mod_show);
 	m_filter_mod_show->SetMinSize( wxSize( 140,-1 ) );
 
