@@ -72,10 +72,17 @@ void ServerEvents::OnLoginInfoComplete()
 	}
     //m_serv.RequestChannels();
     std::vector<ChannelJoinInfo> autojoin = sett().GetChannelsJoin();
-    for ( std::vector<ChannelJoinInfo>::iterator itor = autojoin.begin(); itor != autojoin.end(); itor++ )
+	for ( std::vector<ChannelJoinInfo>::const_iterator itor = autojoin.begin(); itor != autojoin.end(); ++itor )
     {
+		if ( itor->name.IsEmpty() )
+			continue;
+		Channel& chan = m_serv._AddChannel( itor->name );
+		chan.SetPassword( itor->password );
+		ui().OnJoinedChannelSuccessful( chan, itor == autojoin.begin() );
+	}
+	for ( std::vector<ChannelJoinInfo>::const_iterator itor = autojoin.begin(); itor != autojoin.end(); ++itor )
         m_serv.JoinChannel( itor->name, itor->password );
-    }
+
     ui().OnLoggedIn( );
 }
 
@@ -388,9 +395,11 @@ void ServerEvents::OnUserLeftBattle( int battleid, const wxString& nick )
     {
         Battle& battle = m_serv.GetBattle( battleid );
         User& user = battle.GetUser( nick );
+        // this is necessary since the user will be deleted when the gui function is called
+        bool isbot = user.BattleStatus().IsBot();
 		user.BattleStatus().scriptPassword.Clear();
         battle.OnUserRemoved( user );
-        ui().OnUserLeftBattle( battle, user );
+        ui().OnUserLeftBattle( battle, user, isbot );
     }
     catch (std::runtime_error &except)
     {
@@ -566,7 +575,6 @@ void ServerEvents::OnJoinChannelResult( bool success, const wxString& channel, c
     wxLogDebugFunc( _T("") );
     if ( success )
     {
-
         Channel& chan = m_serv._AddChannel( channel );
         chan.SetPassword( m_serv.m_channel_pw[channel] );
         ui().OnJoinedChannelSuccessful( chan );
@@ -660,6 +668,20 @@ void ServerEvents::OnPrivateMessage( const wxString& user, const wxString& messa
     }
 }
 
+void ServerEvents::OnPrivateMessageEx( const wxString& user, const wxString& action, bool fromme )
+{
+	wxLogDebugFunc( _T("") );
+	try
+	{
+		User& who = m_serv.GetUser( user );
+		if (!useractions().DoActionOnUser( UserActions::ActIgnorePM, who.GetNick() ) )
+			ui().OnUserSaidEx( who, action, fromme );
+	}
+	catch (std::runtime_error &except)
+	{
+	}
+}
+
 void ServerEvents::OnChannelList( const wxString& channel, const int& numusers, const wxString& topic )
 {
     ui().mw().OnChannelList( channel, numusers, topic );
@@ -769,7 +791,8 @@ void ServerEvents::OnBattleRemoveBot( int battleid, const wxString& nick )
     {
         Battle& battle = m_serv.GetBattle( battleid );
 		User& user = battle.GetUser( nick );
-		ui().OnUserLeftBattle( battle, user );
+		bool isbot = user.BattleStatus().IsBot();
+		ui().OnUserLeftBattle( battle, user, isbot );
         battle.OnUserRemoved( user );
     }
     catch (std::runtime_error &except)
@@ -955,6 +978,8 @@ void ServerEvents::OnScriptEnd( int battleid )
 
 void ServerEvents::OnFileDownload( bool autolaunch, bool autoclose, bool /*disconnectonrefuse*/, const wxString& FileName, const wxString& url, const wxString& description )
 {
+	if ( sett().IgnoreOfferfile() )
+		return;
 	wxString refinedurl;
 	if ( url.Find(_T("http://")) != wxNOT_FOUND ) refinedurl = url.AfterFirst(_T('/')).AfterFirst(_T('/'));
 	else refinedurl = url;
