@@ -32,6 +32,7 @@
 #include "userlist.h"
 #include "battle.h"
 #include "singleplayerbattle.h"
+#include "qt/noguisingleplayerbattle.h"
 #include "offlinebattle.h"
 #include "user.h"
 #include "iunitsync.h"
@@ -42,9 +43,14 @@
 #endif
 #include "globalsmanager.h"
 
+#ifdef SL_QT_MODE
+	#include <QMessageBox>
+	#include <QProcess>
+#endif
+
 BEGIN_EVENT_TABLE( Spring, wxEvtHandler )
 
-    EVT_COMMAND ( PROC_SPRING, wxEVT_SPRING_EXIT, Spring::OnTerminated )
+	EVT_COMMAND ( PROC_SPRING, wxEVT_SPRING_EXIT, Spring::OnTerminated )
 
 END_EVENT_TABLE()
 
@@ -58,6 +64,9 @@ Spring& spring()
 }
 
 Spring::Spring() :
+	#ifdef SL_QT_MODE
+		qt_process_( 0 ),
+	#endif
         m_process(0),
         m_wx_process(0),
         m_running(false)
@@ -160,6 +169,8 @@ bool Spring::Run( NoGuiSinglePlayerBattle& battle )
 
   wxString path = sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("script.txt");
 
+  wxString cmd = _T("\"") + path + _T("\"");
+
   try
   {
 
@@ -178,7 +189,7 @@ bool Spring::Run( NoGuiSinglePlayerBattle& battle )
     return false;
   }
 
-  return LaunchSpring( _T("\"") + path + _T("\"") );
+  return LaunchSpring( cmd );
 }
 
 bool Spring::Run( OfflineBattle& battle )
@@ -220,7 +231,17 @@ bool Spring::LaunchSpring( const wxString& params  )
         cmd += sep + wxString(_T("Contents")) + sep + wxString(_T("MacOS")) + sep + wxString(_T("spring")); // append app bundle inner path
   #endif
   cmd += _T("\" ") + configfileflags + params;
+  
   wxLogMessage( _T("spring call params: %s"), cmd.c_str() );
+
+#ifdef SL_QT_MODE
+	QMessageBox:: warning ( NULL, "CMD", QString(cmd.mb_str()));
+	qt_process_ = new QProcess;
+	qt_process_->setWorkingDirectory(QString(sett().GetCurrentUsedDataDir().mb_str()));
+	qt_process_->start(QString(cmd.mb_str()));
+	connect( qt_process_, SIGNAL(finished(int, QProcess::ExitStatus )), this, SLOT( OnStopped(int, QProcess::ExitStatus ) ) );
+	connect( qt_process_, SIGNAL(started()), this, SLOT( OnStarted() ) );
+#else
   wxSetWorkingDirectory( sett().GetCurrentUsedDataDir() );
   if ( sett().UseOldSpringLaunchMethod() )
   {
@@ -234,11 +255,23 @@ bool Spring::LaunchSpring( const wxString& params  )
     m_process->SetCommand( cmd );
     m_process->Run();
   }
-
+#endif
   m_running = true;
   return true;
 }
 
+#ifdef SL_QT_MODE
+void Spring::OnStopped( int /*exitCode*/, QProcess::ExitStatus /*exitStatus*/ )
+{
+	m_running = false;
+	emit springStopped( );
+}
+void Spring::OnStarted()
+{
+	m_running = true;
+	emit springStarted();
+}
+#endif
 
 
 void Spring::OnTerminated( wxCommandEvent& event )
