@@ -46,7 +46,7 @@ class SpringLobbyApp : public wxApp, public OnQuitSink<SpringLobbyApp>
 	wxString m_log_file_path;
     bool m_log_window_show;
     bool m_crash_handle_disable;
-    wxString m_customizer_modname;
+	wxString m_customizer_archive_name;
 	wxString m_appname;
 
     DECLARE_EVENT_TABLE()
