@@ -307,23 +307,27 @@ bool TASServer::ExecuteSayCommand( const wxString& cmd )
         Disconnect();
         return true;
     }
-    else if ( subcmd == _T("/changepassword") )
+    else if ( subcmd == _T("/changepassword2") )
     {
-		if ( arrayparams.GetCount() < 2 ) return false;
+		if ( arrayparams.GetCount() < 1 ) return false;
 		wxString oldpassword = sett().GetServerAccountPass( GetServerName() );
-		wxString newpassword;
+		wxString newpassword = GetPasswordHash( params );
 		if  ( oldpassword.IsEmpty() || !sett().GetServerAccountSavePass(GetServerName()) )
 		{
-			oldpassword = GetPasswordHash(arrayparams[1]);
-			newpassword = GetPasswordHash( arrayparams[2] );
-		}
-		else
-		{
-			newpassword = GetPasswordHash( params );
+			m_se->OnServerMessage(_("There is no saved password for this account, please use /changepassword"));
+			return true;
 		}
         SendCmd( _T("CHANGEPASSWORD"), oldpassword + _T(" ") + newpassword );
         return true;
     }
+    else if ( subcmd == _T("/changepassword") )
+    {
+		if ( arrayparams.GetCount() != 2 ) return false;
+		wxString oldpassword = GetPasswordHash(arrayparams[1]);
+		wxString newpassword = GetPasswordHash( arrayparams[2] );
+        SendCmd( _T("CHANGEPASSWORD"), oldpassword + _T(" ") + newpassword );
+        return true;
+    }
     else if ( subcmd == _T("/ping") )
     {
 				Ping();
@@ -813,6 +817,11 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
         }
         m_se->OnPrivateMessage( nick, params, true );
     }
+	else if ( cmd == _T("SAYPRIVATEEX") )
+	{
+		nick = GetWordParam( params );
+		m_se->OnPrivateMessageEx( nick, params, true );
+	}
     else if ( cmd == _T("SAIDPRIVATE") )
     {
         nick = GetWordParam( params );
@@ -862,6 +871,11 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 				}
         m_se->OnPrivateMessage( nick, params, false );
     }
+	else if ( cmd == _T("SAIDPRIVATEEX") )
+	{
+		nick = GetWordParam( params );
+		m_se->OnPrivateMessageEx( nick, params, false );
+	}
     else if ( cmd == _T("JOINBATTLE") )
     {
         id = GetIntParam( params );
@@ -1613,7 +1627,7 @@ void TASServer::SendHostInfo( HostInfo update )
         wxString cmd;
 
         OptionsWrapper::wxStringTripleVec optlistMap = battle.CustomBattleOptions().getOptions( OptionsWrapper::MapOption );
-        for (OptionsWrapper::wxStringTripleVec::iterator it = optlistMap.begin(); it != optlistMap.end(); ++it)
+		for (OptionsWrapper::wxStringTripleVec::const_iterator it = optlistMap.begin(); it != optlistMap.end(); ++it)
         {
 			wxString newcmd = _T("game/mapoptions/") + it->first + _T("=") + it->second.second + _T("\t");
 			if ( cmd.size() + newcmd.size() > 900 ) // should be 1024 add margin for relayhost name and command itself
@@ -1625,7 +1639,7 @@ void TASServer::SendHostInfo( HostInfo update )
 			cmd << newcmd;
         }
         OptionsWrapper::wxStringTripleVec optlistMod = battle.CustomBattleOptions().getOptions( OptionsWrapper::ModOption );
-        for (OptionsWrapper::wxStringTripleVec::iterator it = optlistMod.begin(); it != optlistMod.end(); ++it)
+		for (OptionsWrapper::wxStringTripleVec::const_iterator it = optlistMod.begin(); it != optlistMod.end(); ++it)
         {
 			wxString newcmd = _T("game/modoptions/") + it->first + _T("=") + it->second.second + _T("\t");
 			if ( cmd.size() + newcmd.size() > 900 )// should be 1024 add margin for relayhost name and command itself
@@ -1637,7 +1651,7 @@ void TASServer::SendHostInfo( HostInfo update )
 			cmd << newcmd;
         }
         OptionsWrapper::wxStringTripleVec optlistEng = battle.CustomBattleOptions().getOptions( OptionsWrapper::EngineOption );
-        for (OptionsWrapper::wxStringTripleVec::iterator it = optlistEng.begin(); it != optlistEng.end(); ++it)
+		for (OptionsWrapper::wxStringTripleVec::const_iterator it = optlistEng.begin(); it != optlistEng.end(); ++it)
         {
 			wxString newcmd = _T("game/") + it->first + _T("=") + it->second.second + _T("\t");
 			if ( cmd.size() + newcmd.size() > 900 )// should be 1024 add margin for relayhost name and command itself
@@ -1698,7 +1712,7 @@ void TASServer::SendHostInfo( HostInfo update )
         {
             wxString msg;
             wxString scriptmsg;
-            for ( std::map<wxString, int>::iterator itor = units.begin(); itor != units.end(); itor++ )
+			for ( std::map<wxString, int>::const_iterator itor = units.begin(); itor != units.end(); itor++ )
             {
             	 msg << itor->first + _T(" ");
             	 scriptmsg << _T("game/restrict/") + itor->first + _T("=") + TowxString(itor->second) + _T('\t'); // this is a serious protocol abuse, but on the other hand, the protocol fucking suck and it's unmaintained so it will do for now
@@ -2235,6 +2249,8 @@ void TASServer::UpdateBot( int battleid, User& bot, UserBattleStatus& status )
 
 void TASServer::SendScriptToProxy( const wxString& script )
 {
+  int time = script.Len() / m_sock->GetSendRateLimit(); // calculate time in seconds to upload script
+  DoActionBattle( m_battle_id, wxString::Format(_T("is preparing to start the game, game will start in approximately %d seconds"),time));
   RelayCmd( _T("CLEANSCRIPT") );
   wxStringTokenizer tkzr( script, _T("\n") );
   while ( tkzr.HasMoreTokens() )
@@ -2577,3 +2593,4 @@ IBattle::GameType IntToGameType( int gt )
     };
     return IBattle::GT_ComContinue;
 }
+
