@@ -103,13 +103,13 @@ void TASServer::FillAliasMap()
 		m_command_alias[_T("~")] = _T("TESTLOGINDENY");
 		m_command_alias[_T("")] = _T("ACQUIREUSERID");
 		m_command_alias[_T("")] = _T("USERID");
-		for ( std::map<wxString,wxString>::iterator i = m_command_alias.begin(); i != m_command_alias.end(); i++) m_send_command_alias[i->second] = i->first; //swap content for second map
+		for ( std::map<wxString,wxString>::const_iterator i = m_command_alias.begin(); i != m_command_alias.end(); ++i) m_send_command_alias[i->second] = i->first; //swap content for second map
 }
 
 // returns original if not found
 wxString DecodeTokenMessage( const wxString& cmd )
 {
-		std::map<wxString,wxString>::iterator it = m_command_alias.find( cmd );
+		std::map<wxString,wxString>::const_iterator it = m_command_alias.find( cmd );
 		if ( it != m_command_alias.end() ) return it->second;
 		else return cmd;
 }
@@ -117,7 +117,7 @@ wxString DecodeTokenMessage( const wxString& cmd )
 // returns original if not found
 wxString EncodeTokenMessage( const wxString& cmd )
 {
-		std::map<wxString,wxString>::iterator it = m_send_command_alias.find( cmd );
+		std::map<wxString,wxString>::const_iterator it = m_send_command_alias.find( cmd );
 		if ( it != m_send_command_alias.end() ) return it->second;
 		else return cmd;
 }
