@@ -12,11 +12,20 @@
 #include <winsock2.h>
 #endif // _MSC_VER
 
+#include "torrentwrapper.h"
+
+#include <boost/filesystem/operations.hpp>
+#include <boost/filesystem/path.hpp>
+#include <boost/filesystem/fstream.hpp>
+#include <boost/format.hpp>
+#include <boost/cstdint.hpp>
+
 #include "settings.h"
 #include "utils/conversion.h"
 #include "utils/debug.h"
 #include "socket.h"
 #include "base64.h"
+#include "updater/updatehelper.h"
 
 #include <libtorrent/entry.hpp>
 #include <libtorrent/session.hpp>
@@ -31,11 +40,9 @@
 #endif
 #include <libtorrent/extensions/metadata_transfer.hpp>
 #include <libtorrent/extensions/ut_pex.hpp>
+#include <libtorrent/extensions/smart_ban.hpp>
 
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
-#include <boost/filesystem/fstream.hpp>
-#include <boost/format.hpp>
+#include <libtorrent/alert_types.hpp>
 
 #include <fstream>
 
@@ -49,7 +56,6 @@
 #include <wx/app.h>
 #include <wx/event.h>
 
-#include "torrentwrapper.h"
 #include "utils/customdialogs.h"
 #include "utils/downloader.h"
 #include "utils/uievents.h"
@@ -72,7 +78,7 @@ getDataSubdirForType(const IUnitSync::MediaType type)
     case IUnitSync::map:
         return _T("maps");
     case IUnitSync::mod:
-        return _T("mods");
+		return _T("games");
     default:
         ASSERT_EXCEPTION(false, _T("Unhandled IUnitSync::MediaType value"));
     }
@@ -150,7 +156,10 @@ TorrentWrapper::TorrentWrapper():
         m_started(false)
 {
     wxLogMessage(_T("TorrentWrapper::TorrentWrapper()"));
+	libtorrent::session_settings settings;
+	settings.user_agent= std::string("SL") + STD_STRING(GetSpringLobbyVersion(true));
     m_torr = new libtorrent::session( libtorrent::fingerprint("SL", 0, 0, 0, 0), 0 );
+	m_torr->set_settings( settings );
     try
     {
         m_torr->add_extension(&libtorrent::create_metadata_plugin);
@@ -167,6 +176,14 @@ TorrentWrapper::TorrentWrapper():
     {
         wxLogError( TowxString( e.what() ) );
     }
+	try
+	{
+		m_torr->add_extension(&libtorrent::create_smart_ban_plugin);
+	}
+	catch (std::exception& e)
+	{
+		wxLogError( TowxString( e.what() ) );
+	}
     //these extensions proved o be too problematic on win so i flat out disable them
     #ifndef __WXMSW__
         try
@@ -214,7 +231,7 @@ TorrentWrapper::~TorrentWrapper()
 	//save torrents to resume
 	std::vector<wxString> toResume;
 	TorrenthandleInfoMap infomap = GetHandleInfoMap();
-	TorrenthandleInfoMap::iterator it = infomap.begin();
+	TorrenthandleInfoMap::const_iterator it = infomap.begin();
 	for ( ; it != infomap.end(); ++it )
 	{
 		PlasmaResourceInfo info = it->first;
@@ -465,7 +482,7 @@ void TorrentWrapper::HandleCompleted()
 	int num_completed = 0;
 	{
 	TorrenthandleInfoMap infohandle = GetHandleInfoMap();
-	TorrenthandleInfoMap::iterator it = infohandle.begin();
+	TorrenthandleInfoMap::const_iterator it = infohandle.begin();
 
 	for ( ; it != infohandle.end(); ++it )
 	{
@@ -488,7 +505,7 @@ void TorrentWrapper::HandleCompleted()
 				bool ok = wxCopyFile( source_path, dest_filename );
 				if ( !ok )
 				{
-					wxString msg = wxString::Format( _("File copy from %s to %s failed.\nPlease copy manually and reload maps/mods afterwards"),
+					wxString msg = wxString::Format( _("File copy from %s to %s failed.\nPlease copy manually and reload maps/games afterwards"),
 								source_path.c_str(), dest_filename.c_str() );
 					wxLogError( _T("DL: File copy from %s to %s failed."), source_path.c_str(), dest_filename.c_str() );
 					wxMutexGuiLocker locker;
@@ -523,8 +540,7 @@ void TorrentWrapper::HandleCompleted()
 std::map<wxString,TorrentInfos> TorrentWrapper::CollectGuiInfos()
 {
     std::map<wxString,TorrentInfos> ret;
-    try
-    {
+    try {
 		const TorrenthandleInfoMap& infomap = GetHandleInfoMap();
         TorrentInfos globalinfos;
         libtorrent::session_status session_status = m_torr->status();
@@ -537,8 +553,7 @@ std::map<wxString,TorrentInfos> TorrentWrapper::CollectGuiInfos()
         ret[wxString(_T("global"))] = globalinfos;
 
 		const TorrenthandleVector torrentList = m_torr->get_torrents();
-		for ( TorrenthandleInfoMap::const_iterator i = infomap.begin(); i != infomap.end(); ++i )
-        {
+		for ( TorrenthandleInfoMap::const_iterator i = infomap.begin(); i != infomap.end(); ++i ) {
 			try {
 				TorrentInfos CurrentTorrent;
 				libtorrent::torrent_handle handle = i->second;
@@ -550,16 +565,18 @@ std::map<wxString,TorrentInfos> TorrentWrapper::CollectGuiInfos()
 				CurrentTorrent.numcopies = torrent_status.distributed_copies;
 				CurrentTorrent.filesize = handle.get_torrent_info().total_size();
 
-				int eta_seconds = -1;
-				if ( CurrentTorrent.progress > 0 && CurrentTorrent.inspeed > 0)
-					eta_seconds = int (  (CurrentTorrent.filesize - CurrentTorrent.downloaded ) / CurrentTorrent.inspeed );
+				boost::int64_t eta_seconds = -1;
+				if ( CurrentTorrent.progress > 0 && CurrentTorrent.inspeed > 0) {
+					eta_seconds =  (CurrentTorrent.filesize - (CurrentTorrent.downloaded - torrent_status.total_failed_bytes)) / CurrentTorrent.inspeed;
+				}
 
 				CurrentTorrent.eta = eta_seconds;
 				CurrentTorrent.downloadstatus = getP2PStatusFromHandle( handle );
 				ret[CurrentTorrent.name] = CurrentTorrent;
 			}
-			catch ( libtorrent::invalid_handle& h )
-			{}
+			catch ( libtorrent::invalid_handle& h ) {
+			    wxLogWarning(_T("%s"), h.what());
+			}
         }
     }
     catch (std::exception& e)
@@ -573,6 +590,20 @@ std::map<wxString,TorrentInfos> TorrentWrapper::CollectGuiInfos()
 
 void TorrentWrapper::RemoveInvalidTorrents()
 {
+	#if LIBTORRENT_VERSION_MINOR > 14
+	//remove failed webseeds
+	std::auto_ptr<libtorrent::alert> alert = m_torr->pop_alert();
+	while ( alert.get() )
+	{
+		libtorrent::url_seed_alert* url_alert = libtorrent::alert_cast<libtorrent::url_seed_alert>(alert.get());
+		if( url_alert )
+		{
+			url_alert->handle.remove_url_seed( url_alert->url );
+		}
+		alert = m_torr->pop_alert();
+	}
+	#endif
+
 	TorrenthandleInfoMap& infomap = GetHandleInfoMap();
 	TorrenthandleInfoMap::iterator it = infomap.begin();
 	for ( ; it != infomap.end(); )
