@@ -5,14 +5,12 @@
 
 #include <wx/intl.h>
 #include <vector>
+#include "utils/mixins.hh"
 
 class wxColour;
 class wxImage;
 class wxBitmap;
 
-
-#define wxDefaultBitmap wxBitmap()
-
 wxString RTFtoText( const wxString& rtfinput );
 bool AreColoursSimilar( const wxColour& col1, const wxColour& col2, int mindiff = 10 );
 
@@ -34,6 +32,8 @@ wxBitmap charArr2wxBitmap(const unsigned char * arg, int size);
 wxBitmap charArr2wxBitmapWithBlending(const unsigned char * arg, int size,
             const unsigned char * text, int text_size);
 
+wxBitmap getColourIcon( const wxColour& colour );
+
 //! shrinks/expands image by removing/duplicating rows/columns from the center of the image
 wxImage BorderInvariantResizeImage(  const wxImage& image, int width, int height );
 
@@ -50,7 +50,7 @@ void OpenWebBrowser( const wxString& url );
 
 class wxDateTime;
 //! measures time diff between ctor and dtor, shows result in msg box
-struct TimerMessageBox {
+struct TimerMessageBox: public SL::NonCopyable {
 	//! msg_format must contain exactly one %s to be filled with the elapsed time
 	TimerMessageBox( const wxString& msg_format );
 	~TimerMessageBox();
