@@ -4,13 +4,25 @@
 #include "../defines.h"
 #include <wx/gdicmn.h>
 #include <wx/window.h>
+#include <wx/tooltip.h>
+
+bool main_app_has_focus;
+
+void UpdateMainAppHasFocus( bool focus )
+{
+	main_app_has_focus = focus;
+	wxToolTip::Enable(sett().GetShowTooltips()&&main_app_has_focus);
+}
 
 const wxChar* TooltipEnable(const wxChar* input)
 {
 	#if !defined(HAVE_WX29) || defined(__WXOSX_COCOA__)
-        return sett().GetShowTooltips() ? input : _T("");
+			if (!main_app_has_focus) return _T("");
+			return sett().GetShowTooltips() ? input : _T("");
     #else
-        return sett().GetShowTooltips() ? input : _T("").wc_str();
+			wxString dummy = wxEmptyString;
+			if (!main_app_has_focus) return dummy.wc_str();
+			return sett().GetShowTooltips() ? input : dummy.wc_str();
     #endif
 }
 
