@@ -33,12 +33,12 @@
 #include <curl/easy.h>
 #include "curlhelper.h"
 
-const wxString s_soap_service_url = _T("http://planet-wars.eu/PlasmaServer/Service.asmx?op=DownloadFile");
+const wxString s_soap_service_url = _T("http://zero-k.info/ContentService.asmx?op=DownloadFile");
 
 const wxString s_soap_querytemplate = _T("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n" \
 "<soap12:Envelope xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:soap12=\"http://www.w3.org/2003/05/soap-envelope\">\n"\
 "   <soap12:Body>\n"\
-"       <DownloadFile xmlns=\"http://planet-wars.eu/PlasmaServer/\">\n"\
+"       <DownloadFile xmlns=\"http://tempuri.org/\">\n"\
 "           <internalName>REALNAME</internalName>\n"\
 "       </DownloadFile>\n"\
 "   </soap12:Body>\n"\
@@ -47,7 +47,7 @@ const wxString s_soap_querytemplate = _T("<?xml version=\"1.0\" encoding=\"utf-8
 const wxString s_soap_querytemplate_resourcelist = _T("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n" \
 "<soap12:Envelope xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:soap12=\"http://www.w3.org/2003/05/soap-envelope\">\n"\
 "   <soap12:Body>\n"\
-"       <GetResourceList xmlns=\"http://planet-wars.eu/PlasmaServer/\" />\n"\
+"       <GetResourceList xmlns=\"http://tempuri.org/\" />\n"\
 "   </soap12:Body>\n"\
 "</soap12:Envelope>\0");
 
@@ -63,8 +63,8 @@ PlasmaInterface& plasmaInterface()
   * @todo: document this function
   */
 PlasmaInterface::PlasmaInterface()
-    : m_host ( _T("planet-wars.eu") ),
-    m_remote_path ( _T("/PlasmaServer/Service.asmx") )
+	: m_host ( _T("zero-k.info") ),
+	m_remote_path ( _T("ContentService.asmx") )
 {
 	m_worker_thread.Create();
 	m_worker_thread.SetPriority( WXTHREAD_MIN_PRIORITY );
@@ -94,11 +94,11 @@ PlasmaResourceInfo PlasmaInterface::GetResourceInfo(const wxString& name)
     struct curl_slist* m_pHeaders = NULL;
     // these header lines will overwrite/add to cURL defaults
     m_pHeaders = curl_slist_append(m_pHeaders, "Content-Type: text/xml;charset=UTF-8");//default is formurl-encoded with cURL-POST, that's bad for us
-    m_pHeaders = curl_slist_append(m_pHeaders, "SOAPAction: \"http://planet-wars.eu/PlasmaServer/DownloadFile\"");
+	m_pHeaders = curl_slist_append(m_pHeaders, "SOAPAction: \"http://tempuri.org/DownloadFile\"");
     m_pHeaders = curl_slist_append(m_pHeaders, "Expect:") ;
 
     curl_easy_setopt(curl_handle, CURLOPT_HTTPHEADER, m_pHeaders);
-    curl_easy_setopt(curl_handle, CURLOPT_URL, "http://planet-wars.eu/PlasmaServer/Service.asmx" );
+	curl_easy_setopt(curl_handle, CURLOPT_URL, "http://zero-k.info/ContentService.asmx" );
 	//curl_easy_setopt(curl_handle, CURLOPT_VERBOSE, 1L);
     curl_easy_setopt(curl_handle, CURLOPT_USERAGENT, "libcurl-agent/1.0");
     curl_easy_setopt(curl_handle, CURLOPT_WRITEFUNCTION, wxcurl_stream_write);
@@ -109,23 +109,30 @@ PlasmaResourceInfo PlasmaInterface::GetResourceInfo(const wxString& name)
     curl_easy_setopt(curl_handle, CURLOPT_READFUNCTION, wxcurl_stream_read);
     curl_easy_setopt(curl_handle, CURLOPT_READDATA, (void*)&req);
 
-    CURLcode ret = curl_easy_perform(curl_handle);
-	assert( ret == CURLE_OK );
-	//wxMessageBox( rheader.GetString()  );
+	const CURLcode ret = curl_easy_perform(curl_handle);
+	/* cleanup curl stuff */
+	curl_easy_cleanup(curl_handle);
 
-  /* cleanup curl stuff */
-    curl_easy_cleanup(curl_handle);
-
-    m_buffers[index] = response.GetString();
+	m_buffers[index] = response.GetString();
 
 	PlasmaResourceInfo info;
+	if( ret != CURLE_OK ) {
+		wxLogError( _T("dl curl error:\n%s"), m_buffers[index].c_str() );
+		info.m_type = PlasmaResourceInfo::unknown;
+		return info;
+	}
+
 	try {
 		info = ParseResourceInfoData( index );
+		return info;
 	}
-	catch (...){
-		info.m_type = PlasmaResourceInfo::unknown;
+	catch (assert_exception& a){
+		wxLogError( WX_STRINGC( a.what() ) );
 	}
+	catch ( ... ) {}
+	info.m_type = PlasmaResourceInfo::unknown;
 	return info;
+
 }
 
 PlasmaResourceInfo PlasmaInterface::ParseResourceInfoData( const int buffer_index )
@@ -156,7 +163,9 @@ PlasmaResourceInfo PlasmaInterface::ParseResourceInfoData( const int buffer_inde
 			ASSERT_EXCEPTION( links, _T("Plasma: XMLparser: no webseed section") );
             wxXmlNode* url = links->GetChildren();
             while ( url ) {
-                info.m_webseeds.Add( url->GetNodeContent() );
+				wxString seed_url = url->GetNodeContent();
+				seed_url.Replace(_T(" "),_T("%20"));
+				info.m_webseeds.Add( seed_url );
                 url = url->GetNext();
             }
             wxXmlNode* next = links->GetNext();
@@ -206,7 +215,7 @@ void PlasmaInterface::downloadFile(const wxString& host, const wxString& remote_
     FileDownloading.Connect( host, 80);
 
     wxInputStream* httpstream = FileDownloading.GetInputStream( _T("/") + remote_path );
-    wxLogDebug( _T("downloading file ") + host + _T("/") + remote_path );
+	wxLogDebug( _T("downloading file %s/%s"),host,remote_path );
 
     if ( httpstream )
     {
@@ -230,7 +239,7 @@ bool PlasmaInterface::DownloadTorrentFile( PlasmaResourceInfo& info, const wxStr
 {
     wxString dl_target = destination_directory + wxFileName::GetPathSeparator() + info.m_torrent_filename;
     try {
-        downloadFile( m_host, _T("PlasmaServer/Resources/") + info.m_torrent_filename, dl_target );
+		downloadFile( m_host, _T("Resources/") + info.m_torrent_filename, dl_target );
         info.m_local_torrent_filepath = dl_target;
     }
     catch ( std::exception& e ) {
@@ -262,7 +271,7 @@ void FetchResourceListWorkItem::Run()
 	m_pHeaders = curl_slist_append(m_pHeaders, "Expect:") ;
 
 	curl_easy_setopt(curl_handle, CURLOPT_HTTPHEADER, m_pHeaders);
-	curl_easy_setopt(curl_handle, CURLOPT_URL, "http://planet-wars.eu/PlasmaServer/Service.asmx" );
+	curl_easy_setopt(curl_handle, CURLOPT_URL, "http://zero-k.info/ContentService.asmx" );
 	//curl_easy_setopt(curl_handle, CURLOPT_VERBOSE, 1L);
 	curl_easy_setopt(curl_handle, CURLOPT_USERAGENT, "libcurl-agent/1.0");
 	curl_easy_setopt(curl_handle, CURLOPT_WRITEFUNCTION, wxcurl_stream_write);
@@ -274,14 +283,16 @@ void FetchResourceListWorkItem::Run()
 	curl_easy_setopt(curl_handle, CURLOPT_READDATA, (void*)&req);
 
 	CURLcode ret = curl_easy_perform(curl_handle);
-	assert( ret == CURLE_OK );
-
-  /* cleanup curl stuff */
+	/* cleanup curl stuff */
 	curl_easy_cleanup(curl_handle);
 
-	m_interface->ParseResourceListData( response.GetString() );
-
-    GetGlobalEventSender( GlobalEvents::PlasmaResourceListParsed ).SendEvent( 0 );
+	if ( ret != CURLE_OK ) {
+		GetGlobalEventSender( GlobalEvents::PlasmaResourceListFailedDownload ).SendEvent( 0 );
+	}
+	else {
+		m_interface->ParseResourceListData( response.GetString() );
+		GetGlobalEventSender( GlobalEvents::PlasmaResourceListParsed ).SendEvent( 0 );
+	}
 
 }
 void PlasmaInterface::ParseResourceListData( const wxString& buffer )
